@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 15.3 Debian package creator
-# Release 2019-03-07
+# DaVinci Resolve 15.3.1 Debian package creator
+# Release 2019-04-07
 # By Daniel Tufvesson
 #
 
@@ -36,6 +36,16 @@ create_directory() {
     fi
 }
 
+extract_tgz() {
+    check_command tar
+    if [ -f "$1" ] ; then
+	echo "[EXTRACT] $1 [TO] $2"
+	tar -zxf "$1" -C "$2" $3
+    else
+	echo "[ERROR: MISSING] $1"
+    fi
+}
+
 make_executable() {
     if [ -e "$1" ] ; then
 	echo "[MAKE EXECUTABLE] $1"
@@ -47,7 +57,7 @@ make_executable() {
 }
 
 # Setup variables
-RESOLVE_VERSION=15.3
+RESOLVE_VERSION=15.3.1
 DEB_STEPPING=1
 case $1 in
     studio)
@@ -131,6 +141,10 @@ cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
 SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
 EOF
 
+# Install panel API library
+create_directory ${DEB_DIR}/usr/lib/
+extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/ libDaVinciPanelAPI.so
+
 # Create desktop shortcut
 create_directory ${DEB_DIR}/usr/share/applications/
 cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
